// An older sketch, showing how to build a polygon vertex by
// vertex.  Do this without using classes and objects.

// The X and Y coordinates of all the points in the drawing.
int[] xs;
int[] ys;

// Which point are we currently dragging?  If -1, then we're
// not dragging anything at the moment.
int dragging = -1;

float handle_radius = 10;

void setup()
{
  size( 500, 500 );
  xs = new int[ 5 ];
  ys = new int[ 5 ];
  
  // Just for fun, make a regular polygon.  Trig, amirite?
  for( int idx = 0; idx < 5; ++idx ) {
     float ang = TWO_PI * idx / 5.0;
     xs[idx] = int( 250 + 150 * cos( ang ) );
     ys[idx] = int( 250 + 150 * sin( ang ) );
  }
}

void draw()
{
  background( 80 );
  
  // Here's a way to draw all the line segments defined by the
  // points based on the vertex() function.  It's a bit more
  // elegant than what I showed in class based on line(), and
  // more like A1Q2.
  
  stroke( 255 );
  strokeWeight( 3.0 );
  noFill();
  
  beginShape();
  for( int idx = 0; idx < xs.length; ++idx ) {
    vertex( xs[idx], ys[idx] );
  }
  endShape();
  
  // Now draw the handles.
  stroke( 0 );
  strokeWeight( 0.5 );
  fill( 200 );
  
  for( int idx = 0; idx < xs.length; ++idx ) {
    ellipse( xs[idx], ys[idx], 2*handle_radius, 2*handle_radius );
  }
}

void mousePressed()
{
  dragging = -1;
  // As I said in class, walk backwards through the handles:
  // hit test order is the opposite of draw order.
  for( int idx = xs.length-1; idx >= 0; --idx ) {
    if( dist( xs[idx], ys[idx], mouseX, mouseY ) < handle_radius ) {
      dragging = idx;
      return;
    }
  }
  
  // Ah, if you got this far you must not have clicked on any
  // of the handles.  In that case, create a new point and 
  // add it to the arrays.
  
  // NOTE: after writing this sketch, I discovered that the
  // built-in function append() is exactly the same as my
  // appendToArray() function below!  Nice job, Processing.
  // So you should experiment with renaming "appendToArray"
  // to "append" below, and removing the "appendToArray"
  // helper function entirely. 
  xs = append( xs, mouseX );
  ys = append( ys, mouseY );
  dragging = xs.length - 1;
}

void mouseDragged()
{
  if( dragging != -1 ) {
    xs[dragging] = mouseX;
    ys[dragging] = mouseY;
  }
}