// Now let's make our dots do something useful: they'll
// serve as the handles for a Bezier curve.  The basic idea
// is the same (move four dots around).  But the view is a 
// bit more complicated, since it's really the curve that we
// want to see.

class Dot
{
  int x;
  int y;
  
  Dot( int x, int y )
  {
    this.x = x;
    this.y = y;
  }
}

Dot[] dots;

int which_drag;

// Smaller dots, since they're not the focus.
float radius = 10.0;

void setup()
{
  size( 500, 500 );
  dots = new Dot[] {
      new Dot( 50, 300 ),
      new Dot( 150, 200 ),
      new Dot( 350, 200 ),
      new Dot( 450, 300 ) };
      
  which_drag = -1;
}

void draw()
{
  background( 220 );
  
  // Draw the Bezier curve.  Note that we're doing this
  // *first*.  That's because the handles should be drawn
  // on top of the curve!
  stroke( 0 );
  strokeWeight( 3.0 );
  noFill();
  bezier( 
    dots[0].x, dots[0].y, dots[1].x, dots[1].y,
    dots[2].x, dots[2].y, dots[3].x, dots[3].y );
    
  // For good measure, draw line segments from Point 0
  // to Point 1, and from Point 2 to Point 3.  This
  // mimics Illustrator to some extent -- the line 
  // segments are the tangents at the start and end
  // of the curve.
  stroke( 128 );
  strokeWeight( 1.0 );
  line( dots[0].x, dots[0].y, dots[1].x, dots[1].y );
  line( dots[2].x, dots[2].y, dots[3].x, dots[3].y );
    
  fill( 100 );
  strokeWeight( 1 );
  for ( int idx = 0; idx < 4; ++idx ) {
    if ( which_drag == idx ) {
      stroke( 255, 0, 0 );
    } else {
      stroke( 0, 0, 0 );
    }
    ellipse( dots[idx].x, dots[idx].y, 2.0*radius, 2.0*radius );
  }
}

void mousePressed()
{
  for ( int idx = 0; idx < 4; ++idx ) {
    if ( dist( dots[idx].x, dots[idx].y, mouseX, mouseY ) <= radius ) {
      which_drag = idx;
      break;
    }
  }
}

void mouseDragged()
{
  if ( which_drag != -1 ) {
    dots[which_drag].x += mouseX - pmouseX;
    dots[which_drag].y += mouseY - pmouseY;
  }
}

void mouseReleased()
{
  which_drag = -1;
}